<?php
require __DIR__ . '/../config.php';
requireLogin();

$error = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $title = trim($_POST['title']);
    $date  = trim($_POST['publish_date']);
    $link  = trim($_POST['link']);

    if ($title === '' || $date === '') {
        $error = 'タイトルと公開日は必須です';
    } else {
        $stmt = $pdo->prepare(
            "INSERT INTO announcements (title, publish_date, link) VALUES (:title, :date, :link)"
        );
        $stmt->execute([
            ':title' => $title,
            ':date'  => $date,
            ':link'  => $link
        ]);
        header('Location: announcement_list.php');
        exit;
    }
}
?>
<!DOCTYPE html>
<html lang="ja">
<head>
  <meta charset="UTF-8">
  <title>新規お知らせ作成</title>
  <link rel="stylesheet" href="style.css">
</head>
<body>
  <nav class="navbar">
    <a href="dashboard.php">ダッシュボード</a>
    <a href="logout.php" style="float:right;color:#dc3545;">ログアウト</a>
  </nav>

  <div class="container">
    <h2>新規お知らせ作成</h2>

    <?php if ($error): ?>
      <p style="color:red;"><?= htmlspecialchars($error, ENT_QUOTES) ?></p>
    <?php endif; ?>

    <form method="post">
      <div>
        <label>タイトル</label>
        <input class="form-control" name="title"
               value="<?= htmlspecialchars($_POST['title'] ?? '', ENT_QUOTES) ?>" required>
      </div>

      <div>
        <label>公開日</label>
        <input class="form-control" name="publish_date"
               type="date"
               value="<?= htmlspecialchars($_POST['publish_date'] ?? '', ENT_QUOTES) ?>"
               required>
      </div>

      <div>
        <label>リンク先</label>
        <input class="form-control" name="link"
               placeholder="https://example.com"
               value="<?= htmlspecialchars($_POST['link'] ?? '', ENT_QUOTES) ?>">
      </div>

      <button class="btn btn-primary" type="submit">作成</button>
    </form>

    <p><a href="announcement_list.php">← 一覧に戻る</a></p>
  </div>
</body>
</html>