<?php
require __DIR__ . '/../config.php';
requireLogin();

// ID取得・検証
$id = isset($_GET['id']) ? (int)$_GET['id'] : 0;
if (!$id) {
    header('Location: category_list.php');
    exit;
}

// 既存データ取得
$stmt = $pdo->prepare("SELECT * FROM categories WHERE id = ?");
$stmt->execute([$id]);
$cat = $stmt->fetch(PDO::FETCH_ASSOC);
if (!$cat) {
    header('Location: category_list.php');
    exit;
}

$error = '';
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $name = trim($_POST['name']);
    $slug = trim($_POST['slug']);
    if ($name === '' || $slug === '') {
        $error = '名前とスラグは必須です';
    } else {
        try {
            $stmt = $pdo->prepare("
                UPDATE categories
                SET name = ?, slug = ?
                WHERE id = ?
            ");
            $stmt->execute([$name, $slug, $id]);
            header('Location: category_list.php');
            exit;
        } catch (PDOException $e) {
            if (strpos($e->getMessage(), 'UNIQUE') !== false) {
                $error = 'そのスラグは既に使われています';
            } else {
                $error = 'データベースエラーが発生しました';
            }
        }
    }
}
?>
<!DOCTYPE html>
<html lang="ja">
<head>
  <meta charset="UTF-8">
  <title>カテゴリー編集 (ID <?= $cat['id'] ?>)</title>
  <link rel="stylesheet" href="style.css">
</head>
<body>
  <nav class="navbar">
    <a href="dashboard.php">ダッシュボード</a>
    <a href="logout.php" style="float:right;color:#dc3545;">ログアウト</a>
  </nav>

  <div class="container">
    <h2>カテゴリー編集 (ID <?= $cat['id'] ?>)</h2>

    <?php if ($error): ?>
      <p style="color:red;"><?= htmlspecialchars($error, ENT_QUOTES) ?></p>
    <?php endif; ?>

    <form method="post">
      <div>
        <label>名前
          <input class="form-control"
                 name="name"
                 value="<?= htmlspecialchars($cat['name'], ENT_QUOTES) ?>"
                 required>
        </label>
      </div>

      <div style="margin-bottom: 2rem;">
        <label>スラグ
          <input class="form-control"
                 name="slug"
                 value="<?= htmlspecialchars($cat['slug'], ENT_QUOTES) ?>"
                 required>
        </label>
        <small>（URL用に英小文字・数字・ハイフン等）</small>
      </div>

      <button class="btn btn-primary" type="submit">更新</button>
    </form>

    <p><a href="category_list.php">← カテゴリー一覧に戻る</a></p>
  </div>
</body>
</html>
