<?php
require __DIR__ . '/../config.php';
requireLogin();

// 個別削除処理
if (isset($_GET['delete_id'])) {
    $id = (int)$_GET['delete_id'];
    $pdo->prepare("UPDATE contents SET category_id = NULL WHERE category_id = ?")
        ->execute([$id]);
    $pdo->prepare("DELETE FROM categories WHERE id = ?")
        ->execute([$id]);
    header('Location: category_list.php');
    exit;
}

// カテゴリー取得
$cats = $pdo->query("SELECT * FROM categories ORDER BY name")
            ->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="ja">
<head>
  <meta charset="UTF-8">
  <title>カテゴリー一覧</title>
  <link rel="stylesheet" href="style.css">
</head>
<body>
  <nav class="navbar">
    <a href="dashboard.php">ダッシュボード</a>
    <a href="logout.php" style="float:right;color:#dc3545;">ログアウト</a>
  </nav>

  <div class="container">
    <h2>カテゴリー一覧</h2>

    <!-- 新規作成ボタンをここに -->
    <p>
      <a class="btn btn-primary" href="category_create.php">
        新規カテゴリー作成
      </a>
    </p>

    <?php if (empty($cats)): ?>
      <p>まだカテゴリーが設定されていません。</p>
    <?php else: ?>
      <table class="table">
        <thead>
          <tr>
            <th>ID</th>
            <th>名前</th>
            <th>スラグ</th>
            <th>操作</th>
          </tr>
        </thead>
        <tbody>
          <?php foreach ($cats as $c): ?>
            <tr>
              <td><?= $c['id'] ?></td>
              <td><?= htmlspecialchars($c['name'], ENT_QUOTES) ?></td>
              <td><?= htmlspecialchars($c['slug'], ENT_QUOTES) ?></td>
              <td>
                <a class="btn btn-primary" href="category_edit.php?id=<?= $c['id'] ?>">
                  編集
                </a>
                <a class="btn btn-danger"
                   href="?delete_id=<?= $c['id'] ?>"
                   onclick="return confirm('カテゴリ「<?= htmlspecialchars($c['name'],ENT_QUOTES) ?>」を削除しますか？');">
                  削除
                </a>
              </td>
            </tr>
          <?php endforeach; ?>
        </tbody>
      </table>
    <?php endif; ?>

  </div>
</body>
</html>
