<?php
require __DIR__ . '/../config.php';
requireLogin();

// ダッシュボード上の削除処理 — お知らせ
if (isset($_GET['delete_ann_id'])) {
    $id = (int)$_GET['delete_ann_id'];
    $pdo->prepare("DELETE FROM announcements WHERE id = ?")->execute([$id]);
    header('Location: dashboard.php');
    exit;
}
// ダッシュボード上の削除処理 — コンテンツ
if (isset($_GET['delete_content_id'])) {
    $id = (int)$_GET['delete_content_id'];
    $pdo->prepare("DELETE FROM contents WHERE id = ?")->execute([$id]);
    header('Location: dashboard.php');
    exit;
}

// 最新お知らせ 5 件取得
$anns = $pdo->query(
    "SELECT * FROM announcements ORDER BY publish_date DESC, id DESC LIMIT 5"
)->fetchAll(PDO::FETCH_ASSOC);

// 最新コンテンツ 5 件取得
$items = $pdo->query(
    "SELECT c.*, COALESCE(cat.name,'未設定') AS category
     FROM contents AS c
     LEFT JOIN categories AS cat ON c.category_id = cat.id
     ORDER BY c.created_at DESC LIMIT 5"
)->fetchAll(PDO::FETCH_ASSOC);
?>
<!DOCTYPE html>
<html lang="ja">
<head>
  <meta charset="UTF-8">
  <title>Simple CMS ダッシュボード</title>
  <link rel="stylesheet" href="style.css">
</head>
<body>
  <nav class="navbar">
    Simple CMS
    <a href="logout.php" style="float:right;color:#dc3545;">ログアウト</a>
  </nav>

  <div class="container">
    <h2 style="margin-bottom: 4rem;">ダッシュボード</h2>

    <!-- お知らせブロック -->
    <section>
      <h3>最新のお知らせ</h3>
      <p><a class="btn btn-primary" href="announcement_create.php">新規登録</a>
	  <a class="btn btn-primary" href="announcement_list.php">一覧</a></p>
      <?php if (empty($anns)): ?>
        <p>まだお知らせはありません。</p>
      <?php else: ?>
        <table class="table">
          <thead>
            <tr>
              <th>ID</th>
              <th>タイトル</th>
              <th>公開日</th>
              <th>操作</th>
            </tr>
          </thead>
          <tbody>
            <?php foreach ($anns as $a): ?>
            <tr>
              <td><?= $a['id'] ?></td>
              <td><?= htmlspecialchars($a['title'], ENT_QUOTES) ?></td>
              <td><?= htmlspecialchars($a['publish_date'], ENT_QUOTES) ?></td>
              <td>
                <a class="btn btn-primary" href="announcement_edit.php?id=<?= $a['id'] ?>">編集</a>
                <a class="btn btn-danger" href="dashboard.php?delete_ann_id=<?= $a['id'] ?>" onclick="return confirm('ID <?= $a['id'] ?> を削除しますか？');">削除</a>
              </td>
            </tr>
            <?php endforeach; ?>
          </tbody>
        </table>
      <?php endif; ?>
    </section>

    <!-- カテゴリーブロック -->
    <section style="margin-top:4rem;">
      <h3>最新のリスト</h3>
      <p><a class="btn btn-primary" href="content_create.php">新規登録</a>
	  <a class="btn btn-primary" href="content_list.php">一覧</a>
	  <a class="btn btn-secondary" href="category_list.php">カテゴリー追加・編集</a></p>
      <?php if (empty($items)): ?>
        <p>まだリストはありません。</p>
      <?php else: ?>
        <table class="table">
          <thead>
            <tr>
              <th>ID</th>
              <th>タイトル</th>
              <th>カテゴリー</th>
              <th>登録日時</th>
              <th>操作</th>
            </tr>
          </thead>
          <tbody>
            <?php foreach ($items as $r): ?>
            <tr>
              <td><?= $r['id'] ?></td>
              <td><?= htmlspecialchars($r['title'], ENT_QUOTES) ?></td>
              <td><?= htmlspecialchars($r['category'], ENT_QUOTES) ?></td>
              <td><?= $r['created_at'] ?></td>
              <td>
                <a class="btn btn-primary" href="content_edit.php?id=<?= $r['id'] ?>">編集</a>
                <a class="btn btn-danger" href="dashboard.php?delete_content_id=<?= $r['id'] ?>" onclick="return confirm('ID <?= $r['id'] ?> を削除しますか？');">削除</a>
              </td>
            </tr>
            <?php endforeach; ?>
          </tbody>
        </table>
      <?php endif; ?>
    </section>

  </div>
</body>
</html>
